summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--stream/cache.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/stream/cache.c b/stream/cache.c
index 95ece34a8c..ad1277fb85 100644
--- a/stream/cache.c
+++ b/stream/cache.c
@@ -702,7 +702,9 @@ int stream_cache_init(stream_t *cache, stream_t *stream,
}
s->cache_thread_running = true;
- // wait until cache is filled at least prefill_init %
+ // wait until cache is filled with at least min bytes
+ if (min < 1)
+ return 1;
for (;;) {
if (stream_check_interrupt(cache))
return 0;